<?php

namespace Litecms\Demo\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\Demo\Http\Requests\DemoRequest;
use Litecms\Demo\Models\Demo;

/**
 * Admin web controller class.
 */
class DemoWorkflowController extends BaseController
{

    /**
     * Workflow controller function for demo.
     *
     * @param Model   $demo
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(DemoRequest $request, Demo $demo, $step)
    {

        try {

            $demo->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('demo::demo.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/demo/demo/' . $demo->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/demo/demo/' . $demo->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for demo.
     *
     * @param Model   $demo
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Demo $demo, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $demo->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('demo::demo.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('demo::admin.demo.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('demo::admin.demo.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('demo::admin.demo.message', $data)->render();

        }

    }
}
