<?php

namespace Litecms\Demo\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Litecms\Demo\Models\Demo;

class DemoAction
{
    /**
     * Perform the complete action.
     *
     * @param Demo $demo
     *
     * @return Demo
     */
    public function complete(Demo $demo)
    {
        try {
            $demo->status = 'complete';
            return $demo->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Demo $demo
     *
     * @return Demo
     */public function verify(Demo $demo)
    {
        try {
            $demo->status = 'verify';
            return $demo->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Demo $demo
     *
     * @return Demo
     */public function approve(Demo $demo)
    {
        try {
            $demo->status = 'approve';
            return $demo->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Demo $demo
     *
     * @return Demo
     */public function publish(Demo $demo)
    {
        try {
            $demo->status = 'publish';
            return $demo->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Demo $demo
     *
     * @return Demo
     */
    public function archive(Demo $demo)
    {
        try {
            $demo->status = 'archive';
            return $demo->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Demo $demo
     *
     * @return Demo
     */
    public function unpublish(Demo $demo)
    {
        try {
            $demo->status = 'unpublish';
            return $demo->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
