<?php

namespace Litecms\Demo\Workflow;

use Litecms\Demo\Models\Demo;
use Validator;

class DemoValidator
{

    /**
     * Determine if the given demo is valid for complete status.
     *
     * @param Demo $demo
     *
     * @return bool / Validator
     */
    public function complete(Demo $demo)
    {
        return Validator::make($demo->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given demo is valid for verify status.
     *
     * @param Demo $demo
     *
     * @return bool / Validator
     */
    public function verify(Demo $demo)
    {
        return Validator::make($demo->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given demo is valid for approve status.
     *
     * @param Demo $demo
     *
     * @return bool / Validator
     */
    public function approve(Demo $demo)
    {
        return Validator::make($demo->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given demo is valid for publish status.
     *
     * @param Demo $demo
     *
     * @return bool / Validator
     */
    public function publish(Demo $demo)
    {
        return Validator::make($demo->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given demo is valid for archive status.
     *
     * @param Demo $demo
     *
     * @return bool / Validator
     */
    public function archive(Demo $demo)
    {
        return Validator::make($demo->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given demo is valid for unpublish status.
     *
     * @param Demo $demo
     *
     * @return bool / Validator
     */
    public function unpublish(Demo $demo)
    {
        return Validator::make($demo->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
